@@ -1,5 +1,6 @@
 import math
-from datetime import timedelta
+from datetime import timedelta, datetime
+import sys
 
 import singer
 from singer import metrics, metadata, Transformer, utils
@@ -175,9 +176,11 @@ def sync_endpoint(
         parent_id=None,
         account_sid=None):
     static_params = endpoint_config.get('params', {})
+    synch_since_bookmark = endpoint_config.get('synch_since_bookmark')
     bookmark_query_field_from = endpoint_config.get('bookmark_query_field_from')
     bookmark_query_field_to = endpoint_config.get('bookmark_query_field_to')
     data_key = endpoint_config.get('data_key', 'data')
+    stringified_json_keys = endpoint_config.get('stringified_json_keys')
     id_fields = endpoint_config.get('key_properties')
 
     start_window, end_window, date_window_days, now_datetime, last_datetime, max_bookmark_value = \
@@ -206,6 +209,20 @@ def sync_endpoint(
             params[bookmark_query_field_from] = strftime(start_window)[:10]  # truncate date
             params[bookmark_query_field_to] = strftime(end_window)[:10]  # truncate date
 
+        if synch_since_bookmark and bookmark_query_field_from:
+            current_stream_bookmark_string = state.get('value', {}).get('bookmarks', {}).get(stream_name)
+
+            # if we have a bookmark for the given stream, use that one
+            if current_stream_bookmark_string is not None:
+                start_datetime = datetime.strptime(current_stream_bookmark_string,
+                                                                       '%Y-%m-%dT%H:%M:%S.%fZ')
+                start_datetime_string = start_datetime.strftime('%Y-%m-%dT%H:%M:%SZ')
+            # if don't, then take the start_date
+            else:
+                start_datetime_string = start_date
+            # assign the synching param to the parameters
+            params[bookmark_query_field_from] = start_datetime_string
+
         # pagination: loop thru all pages of data using next (if not None)
         page = 0
         api_version = endpoint_config.get('api_version')
@@ -268,20 +285,20 @@ def sync_endpoint(
             data_dict = {}
             if data_key in data:
                 if isinstance(data[data_key], list):
-                    transformed_data = transform_json(data, data_key)
+                    transformed_data = transform_json(data, data_key, stringified_json_keys)
                 elif isinstance(data[data_key], dict):
                     data_list.append(data[data_key])
                     data_dict[data_key] = data_list
-                    transformed_data = transform_json(data_dict, data_key)
+                    transformed_data = transform_json(data_dict, data_key, stringified_json_keys)
             else:  # data_key not in data
                 if isinstance(data, list):
                     data_list = data
                     data_dict[data_key] = data_list
-                    transformed_data = transform_json(data_dict, data_key)
+                    transformed_data = transform_json(data_dict, data_key, stringified_json_keys)
                 elif isinstance(data, dict):
                     data_list.append(data)
                     data_dict[data_key] = data_list
-                    transformed_data = transform_json(data_dict, data_key)
+                    transformed_data = transform_json(data_dict, data_key, stringified_json_keys)
 
             # Process records and get the max_bookmark_value and record_count for the set of records
             if stream_name in selected_streams:
